==> freecad_0.17%2Bdfsg1.orig.tar.gz: FreeCAD-0.17/src/Mod/MeshPart/Gui/Resources/translations/MeshPart_zh-CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh-CN" sourcelanguage="en">
  <context>
    <name>CmdMeshPartCurveOnMesh</name>
    <message>
      <location filename="../../Command.cpp" line="+245"/>
      <source>Mesh</source>
      <translation>网格</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Curve on mesh...</source>
      <translation>网格上的曲线......</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Curve on mesh</source>
      <translation>网格上的曲线</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartMesher</name>
    <message>
      <location line="-191"/>
      <source>Mesh</source>
      <translation>网格</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create mesh from shape...</source>
      <translation>从形体创建网格...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Tessellate shape</source>
      <translation>细分形状</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartSection</name>
    <message>
      <location line="+106"/>
      <source>Mesh</source>
      <translation>网格</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create section from mesh and plane</source>
      <translation>从网格和平面创建剖面</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Section</source>
      <translation>截面</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartTrimByPlane</name>
    <message>
      <location line="-85"/>
      <source>Mesh</source>
      <translation>网格</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Trim mesh with a plane</source>
      <translation>以平面修剪网格</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+1"/>
      <source>Trims a mesh with a plane</source>
      <translation>以平面修剪网格</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::CurveOnMeshHandler</name>
    <message>
      <location filename="../../CurveOnMesh.cpp" line="+353"/>
      <source>Create</source>
      <translation>创建</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Close wire</source>
      <translation>封闭线</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Clear</source>
      <translation>清除</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Cancel</source>
      <translation>取消</translation>
    </message>
    <message>
      <location line="+208"/>
      <source>Wrong mesh picked</source>
      <translation>错误的网格选择</translation>
    </message>
    <message>
      <location line="+40"/>
      <source>No point was picked</source>
      <translation>没有点被选</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::TaskCurveOnMesh</name>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="+14"/>
      <source>Curve on mesh</source>
      <translation>网格上的曲线</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Wire</source>
      <translation>线框</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Snap tolerance to vertexes</source>
      <translation>对顶点的对齐公差</translation>
    </message>
    <message>
      <location line="+7"/>
      <source> px</source>
      <translation> px</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Split threshold</source>
      <translation>打印阈值</translation>
    </message>
    <message>
      <location line="+26"/>
      <source>Spline Approximation</source>
      <translation>样条逼近</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Tolerance to mesh</source>
      <translation>网格公差</translation>
    </message>
    <message>
      <location line="+26"/>
      <source>Continuity</source>
      <translation>连续性</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Maximum curve degree</source>
      <translation>最大曲率</translation>
    </message>
    <message>
      <location line="+24"/>
      <source>Start</source>
      <translation>开始</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::Tessellation</name>
    <message>
      <location filename="../../Tessellation.ui" line="+14"/>
      <source>Tessellation</source>
      <translation>曲面细分</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Shapes</source>
      <translation>形状</translation>
    </message>
    <message>
      <location line="+8"/>
      <source>Meshing options</source>
      <translation>网格选项</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Standard</source>
      <translation>标准</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Mefisto</source>
      <translation>Mefisto</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Netgen</source>
      <translation>Netgen</translation>
    </message>
    <message>
      <location line="+81"/>
      <source>Define segments by face colors</source>
      <translation>按面颜色来分区段</translation>
    </message>
    <message>
      <location line="-7"/>
      <source>Apply face colors to mesh</source>
      <translation>将面颜色应用于网布上</translation>
    </message>
    <message>
      <location line="-35"/>
      <source>Angular deviation:</source>
      <translation>角偏差:</translation>
    </message>
    <message>
      <location line="+28"/>
      <source>Relative surface deviation</source>
      <translation>相对表面偏差</translation>
    </message>
    <message>
      <location line="+40"/>
      <source>Maximum edge length:</source>
      <translation>最大边的长度：</translation>
    </message>
    <message>
      <location line="+44"/>
      <source>Fineness:</source>
      <translation>精细度：</translation>
    </message>
    <message>
      <location line="+17"/>
      <source>Very coarse</source>
      <translation>非常粗糙</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Coarse</source>
      <translation>粗糙</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Moderate</source>
      <translation>中等</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Fine</source>
      <translation>精细</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Very fine</source>
      <translation>非常精细</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>User defined</source>
      <translation>用户自定义</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Mesh size grading:</source>
      <translation>网格大小分级：</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Elements per edge:</source>
      <translation>每条边多少单元：</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Elements per curvature radius:</source>
      <translation>每曲率半径多少单元：</translation>
    </message>
    <message>
      <location line="+31"/>
      <source>Optimize surface</source>
      <translation>优化曲面</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Second order elements</source>
      <translation>二阶元素</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Quad dominated</source>
      <translation>四角形为主</translation>
    </message>
    <message>
      <source>Settings</source>
      <translation>设置</translation>
    </message>
    <message>
      <location line="-293"/>
      <source>Surface deviation:</source>
      <translation>表面偏差:</translation>
    </message>
    <message>
      <source>Max. edge length:</source>
      <translation>最大边长:</translation>
    </message>
    <message>
      <location filename="../../Tessellation.cpp" line="+225"/>
      <source>Select a shape for meshing, first.</source>
      <translation>请先选择需要网格化的形状.</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>No such document '%1'.</source>
      <translation>无此文档 '%1'。</translation>
    </message>
  </context>
  <context>
    <name>MeshPart_Section</name>
    <message>
      <location filename="../../Command.cpp" line="+93"/>
      <source>Select plane</source>
      <translation>选取平面</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Please select a plane at which you section the mesh.</source>
      <translation>请选取一个您修剪网格的平面</translation>
    </message>
  </context>
  <context>
    <name>MeshPart_TrimByPlane</name>
    <message>
      <location line="-85"/>
      <source>Select plane</source>
      <translation>选取平面</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Please select a plane at which you trim the mesh.</source>
      <translation>请选取一个您修剪网格的平面</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+36"/>
      <source>MeshPart</source>
      <translation>网格零件</translation>
    </message>
  </context>
</TS>

==> freecad_0.18~pre1%2Bdfsg1.orig.tar.gz: FreeCAD-0.18_pre/src/Mod/MeshPart/Gui/Resources/translations/MeshPart_zh-CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh-CN" sourcelanguage="en">
  <context>
    <name>CmdMeshPartCurveOnMesh</name>
    <message>
      <location filename="../../Command.cpp" line="+290"/>
      <source>Mesh</source>
      <translation>网格</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Curve on mesh...</source>
      <translation>网格上的曲线......</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Curve on mesh</source>
      <translation>网格上的曲线</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartMesher</name>
    <message>
      <location line="-235"/>
      <source>Mesh</source>
      <translation>网格</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create mesh from shape...</source>
      <translation>从形体创建网格...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Tessellate shape</source>
      <translation>细分形状</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartSection</name>
    <message>
      <location line="+150"/>
      <source>Mesh</source>
      <translation>网格</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create section from mesh and plane</source>
      <translation>从网格和平面创建剖面</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Section</source>
      <translation>截面</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartTrimByPlane</name>
    <message>
      <location line="-129"/>
      <source>Mesh</source>
      <translation>网格</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Trim mesh with a plane</source>
      <translation>以平面修剪网格</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+1"/>
      <source>Trims a mesh with a plane</source>
      <translation>以平面修剪网格</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::CurveOnMeshHandler</name>
    <message>
      <location filename="../../CurveOnMesh.cpp" line="+353"/>
      <source>Create</source>
      <translation>创建</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Close wire</source>
      <translation>封闭线</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Clear</source>
      <translation>清除</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Cancel</source>
      <translation>取消</translation>
    </message>
    <message>
      <location line="+208"/>
      <source>Wrong mesh picked</source>
      <translation>错误的网格选择</translation>
    </message>
    <message>
      <location line="+40"/>
      <source>No point was picked</source>
      <translation>没有点被选</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::TaskCurveOnMesh</name>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="+14"/>
      <source>Curve on mesh</source>
      <translation>网格上的曲线</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Wire</source>
      <translation>线框</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Snap tolerance to vertexes</source>
      <translation>对顶点的对齐公差</translation>
    </message>
    <message>
      <location line="+7"/>
      <source> px</source>
      <translation> px</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Split threshold</source>
      <translation>拆分阈值</translation>
    </message>
    <message>
      <location line="+26"/>
      <source>Spline Approximation</source>
      <translation>样条逼近</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Tolerance to mesh</source>
      <translation>网格公差</translation>
    </message>
    <message>
      <location line="+26"/>
      <source>Continuity</source>
      <translation>连续性</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Maximum curve degree</source>
      <translation>最大曲率</translation>
    </message>
    <message>
      <location line="+24"/>
      <source>Start</source>
      <translation>开始</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::Tessellation</name>
    <message>
      <location filename="../../Tessellation.ui" line="+14"/>
      <source>Tessellation</source>
      <translation>曲面细分</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Shapes</source>
      <translation>形状</translation>
    </message>
    <message>
      <location line="+8"/>
      <source>Meshing options</source>
      <translation>网格选项</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Standard</source>
      <translation>标准</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Mefisto</source>
      <translation>Mefisto</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Netgen</source>
      <translation>Netgen</translation>
    </message>
    <message>
      <location line="+81"/>
      <source>Define segments by face colors</source>
      <translation>按面颜色来分区段</translation>
    </message>
    <message>
      <location line="-7"/>
      <source>Apply face colors to mesh</source>
      <translation>将面颜色应用于网格上</translation>
    </message>
    <message>
      <location line="-35"/>
      <source>Angular deviation:</source>
      <translation>角偏差:</translation>
    </message>
    <message>
      <location line="+28"/>
      <source>Relative surface deviation</source>
      <translation>相对表面偏差</translation>
    </message>
    <message>
      <location line="+40"/>
      <source>Maximum edge length:</source>
      <translation>最大边的长度：</translation>
    </message>
    <message>
      <location line="+44"/>
      <source>Fineness:</source>
      <translation>精细度：</translation>
    </message>
    <message>
      <location line="+17"/>
      <source>Very coarse</source>
      <translation>非常粗糙</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Coarse</source>
      <translation>粗糙</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Moderate</source>
      <translation>中等</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Fine</source>
      <translation>精细</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Very fine</source>
      <translation>非常精细</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>User defined</source>
      <translation>用户自定义</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Mesh size grading:</source>
      <translation>网格大小分级：</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Elements per edge:</source>
      <translation>每条边多少单元：</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Elements per curvature radius:</source>
      <translation>每曲率半径多少单元：</translation>
    </message>
    <message>
      <location line="+31"/>
      <source>Optimize surface</source>
      <translation>优化曲面</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Second order elements</source>
      <translation>二阶元素</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Quad dominated</source>
      <translation>四角形为主</translation>
    </message>
    <message>
      <source>Settings</source>
      <translation>设置</translation>
    </message>
    <message>
      <location line="-293"/>
      <source>Surface deviation:</source>
      <translation>表面偏差:</translation>
    </message>
    <message>
      <source>Max. edge length:</source>
      <translation>最大边长:</translation>
    </message>
    <message>
      <location filename="../../Tessellation.cpp" line="+226"/>
      <source>Select a shape for meshing, first.</source>
      <translation>请先选择需要网格化的形状.</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>No such document '%1'.</source>
      <translation>无此文档 '%1'。</translation>
    </message>
  </context>
  <context>
    <name>MeshPart_Section</name>
    <message>
      <location filename="../../Command.cpp" line="+137"/>
      <source>Select plane</source>
      <translation>选取平面</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Please select a plane at which you section the mesh.</source>
      <translation>请选取一个您修剪网格的平面</translation>
    </message>
  </context>
  <context>
    <name>MeshPart_TrimByPlane</name>
    <message>
      <location line="-129"/>
      <source>Select plane</source>
      <translation>选取平面</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Please select a plane at which you trim the mesh.</source>
      <translation>请选取一个您修剪网格的平面</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Trim by plane</source>
      <translation>平面修剪</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Select the side you want to keep.</source>
      <translation>选择要保留的一侧。</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Inner</source>
      <translation>内部</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Outer</source>
      <translation>外部</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Split</source>
      <translation>分割</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+36"/>
      <source>MeshPart</source>
      <translation>网格零件</translation>
    </message>
  </context>
</TS>
